/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: introviewtextbrowser.h 225 2005-06-13 12:57:21Z cstim $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/



#ifndef KBANKING_INTROVIEWTEXTBROWSER_H
#define KBANKING_INTROVIEWTEXTBROWSER_H


#include <qtextbrowser.h>

class IntroViewTextBrowser: public QTextBrowser {
public:
  IntroViewTextBrowser(QWidget *parent=0, const char *name=0);
  ~IntroViewTextBrowser();
  virtual void setSource(const QString &name);
};


// Note: For simplicity, the implementations are in the file
// introview.cpp . However, this class declaration needs to be in
// a separate file instead of introview.h because the uic of qt4
// will otherwise get totally confused.

#endif /* KBANKING_INTROVIEWTEXTBROWSER_H */



